
/* GENERATED CODE... DO NOT EDIT */

/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA.
 *
 * Copyright (C) 2012 Lanedo GmbH
 * Copyright (C) 2012-2022 Aleksander Morgado <aleksander@aleksander.es>
 */


#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>

#include "qmi-enums.h"
#include "qmi-enums-ims.h"
#include "qmi-message.h"
#include "qmi-client.h"

#ifndef __LIBQMI_GLIB_QMI_IMS__
#define __LIBQMI_GLIB_QMI_IMS__

G_BEGIN_DECLS


/* messages unsupported in collection */
/* HAVE_QMI_MESSAGE_IMS_SET_IMS_SERVICES_ENABLED_SETTING */
/* HAVE_QMI_MESSAGE_IMS_GET_IMS_SERVICES_ENABLED_SETTING */
/* HAVE_QMI_INDICATION_IMS_IMS_SERVICES_ENABLED_SETTING */
/* HAVE_QMI_MESSAGE_IMS_BIND */

/* HAVE_QMI_SERVICE_IMS */

G_END_DECLS

#endif /* __LIBQMI_GLIB_QMI_IMS__ */
